# BacDive Utils

Command-line utilities for downloading [BacDive](https://bacdive.dsmz.de/api/bacdive/) entries and merging PNU with the NCBI taxonomy.

## Python utilities

### `dsmz.py`

A library containing base classes for wrapping REST APIs provided by DSMZ.

See: https://www.dsmz.de/services/online-tools

### `bacdive.py`

Python wrapper for downloading DSMZ catalog entries.
This script may be used as a library or in command-line.

See: https://bacdive.dsmz.de/api/bacdive/

### `pnu.py`

Python wrapper for downloading LPSN taxa.
This script may be used as a library or in command-line.

See: https://bacdive.dsmz.de/api/pnu/

## Configuration

In order to use the BacDive API, you must register a valid e-mail address: https://bacdive.dsmz.de/api/bacdive/registration/register/

Once the registration process is completed, write the BacDive password into a file.
**Set this file permissions as `0600` in order to prevent other users to access it**.

Open `config.yml` and set the following variables:

* `BACDIVE_USER` and `BACDIVE_PASSWORD_FILE`: the e-mail registered to BacDive and the password file.
* `ALVISNLP`: the path to AlvisNLP binary.
* `TAXA_FILE`: path to the `taxa+id_microorganisms.txt` file.
* `OUTDIR`: the path to the directory where to store results.

## Download DSMZ entries

̀``shell

snakemake --snakefile dsmz-download.snakefile --cores 1
```

**Downloading the whole DSMZ takes a long time**.
Depending on the bandwith, it takes between 6 and 10 hours.

As in february 2021, the whole catalog includes more than 80k entries and takes approximately 700MB in XML format.

## Match DSMZ strains to NCBI

```shell

snakemake --snakefile dsmz-match.snakefile --cores 1
```

This step uses the following files: `dsmz-match.plan`, `bacdive2alvisnlp.xslt` and whichever file specified in the configuration file as `TAXA_FILE`.

### Output files

The DSMZ match results are written in the `dsmz-match` directory in the output directory.

#### `dispatch-report.txt`

A tabular file where each line represents a DSMZ catalog entry.

* `ENTRY`: name of the catalog entry file.
* `DISPATCH`: dipatch decision
  * `append`: new strain appended to NCBI species or NCBI subspecies
  * `append-species`: new strain and lineage appended to NCBI superspecific taxon
  * `equivalent`: equivalence with NCBI strain
  * `type material`: equivelence with NCBI species or subspecies given as type strain
  * `no-number`: strain has no designation or number
  * `fail`: no match at any taxonomic level

#### `dsmz-nodes.txt` 

Files in the format of NCBI Taxonomy `nodes.dmp` and `names.dmp` that contains all additions.
